Returns the (dx, dy) offsets of cells at exact distance d from the
origin under the chosen ring shape. The origin itself is excluded.
Usage
ring_offsets(d, ring_type = c("manhattan", "chebyshev"))Returns the (dx, dy) offsets of cells at exact distance d from the
origin under the chosen ring shape. The origin itself is excluded.
ring_offsets(d, ring_type = c("manhattan", "chebyshev"))